summaryrefslogtreecommitdiff
path: root/comparison.h
diff options
context:
space:
mode:
authorDaniel Wilhelm <daniel@wili.li>2014-04-18 17:08:06 +0200
committerDaniel Wilhelm <daniel@wili.li>2014-04-18 17:08:06 +0200
commitfbe76102e941b9f1edaf236788e42678f05fdf9a (patch)
treef5f538316019fa89be8dc478103490c3a826f3ac /comparison.h
parent3.8 (diff)
downloadFreeFileSync-fbe76102e941b9f1edaf236788e42678f05fdf9a.tar.gz
FreeFileSync-fbe76102e941b9f1edaf236788e42678f05fdf9a.tar.bz2
FreeFileSync-fbe76102e941b9f1edaf236788e42678f05fdf9a.zip
3.9
Diffstat (limited to 'comparison.h')
-rw-r--r--comparison.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/comparison.h b/comparison.h
index e6d95d40..ac22104c 100644
--- a/comparison.h
+++ b/comparison.h
@@ -7,13 +7,13 @@
#ifndef COMPARISON_H_INCLUDED
#define COMPARISON_H_INCLUDED
-#include "fileHierarchy.h"
-#include "library/processXml.h"
-#include "library/statusHandler.h"
+#include "file_hierarchy.h"
+#include "library/process_xml.h"
+#include "library/status_handler.h"
#include "structures.h"
-namespace FreeFileSync
+namespace ffs3
{
struct FolderPairCfg
@@ -55,10 +55,11 @@ private:
void compareByTimeSize(const std::vector<FolderPairCfg>& directoryPairsFormatted, FolderComparison& output) const;
void compareByContent( const std::vector<FolderPairCfg>& directoryPairsFormatted, FolderComparison& output) const;
- //create comparison result table and fill category except for files existing on both sides
- void performBaseComparison(BaseDirMapping& output, std::vector<FileMapping*>& appendUndefined) const;
+ //create comparison result table and fill category except for files existing on both sides: undefinedFiles and undefinedLinks are appended!
+ void performBaseComparison(BaseDirMapping& output, std::vector<FileMapping*>& undefinedFiles, std::vector<SymLinkMapping*>& undefinedLinks) const;
- void categorizeSymlink(SymLinkMapping* linkObj) const;
+ void categorizeSymlinkByTime(SymLinkMapping* linkObj) const;
+ void categorizeSymlinkByContent(SymLinkMapping* linkObj) const;
//buffer accesses to the same directories; useful when multiple folder pairs are used
class DirectoryBuffer;
bgstack15